shakespearelang
===============

.. image:: https://codeclimate.com/github/zmbc/shakespearelang/badges/gpa.svg
   :target: https://codeclimate.com/github/zmbc/shakespearelang
   :alt: Code Climate

.. image:: https://badge.fury.io/py/shakespearelang.svg
   :target: https://badge.fury.io/py/shakespearelang
   :alt: PyPI version


A friendly interpreter for the Shakespeare Programming Language, implemented in
Python.

What is the Shakespeare Programming Language?
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

The Shakespeare Programming Language (SPL) is a programming language
with source code that looks like Shakespeare's plays. The language is
Turing complete, so theoretically just as powerful as any other
language. It's a lot of fun to write but not very practical. More info can be
found `on Wikipedia`_.

Note: Shakespeare's actual plays are not valid SPL. SPL does not aim to
provide backwards compatibility with legacy code written ~400 years ago.

Installation
^^^^^^^^^^^^

.. code-block::

  pip install shakespearelang
  # Or however else you install things. You do you.

Documentation
^^^^^^^^^^^^^

For more on how to use shakespearelang, see `the docs`_.

Contributing
^^^^^^^^^^^^

Your contributions would be much appreciated! See `CONTRIBUTING.md`_.

.. _on Wikipedia: https://en.wikipedia.org/wiki/Shakespeare_Programming_Language

.. _the docs: https://shakespearelang.com/

.. _CONTRIBUTING.md: https://github.com/zmbc/shakespearelang/blob/main/CONTRIBUTING.md
